# Table of Contents

- [ai-agent-discovery-inbox](<./ai-agent-discovery-inbox.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [AI Agent Discovery Inbox](<./AI-Agent-Discovery-Inbox.md>)
  - [Overview](<./AI-Agent-Discovery-Inbox/Overview.md>)
  - [Discovery Suggestions for AI Agents](<./AI-Agent-Discovery-Inbox/Discovery-Suggestions-for-AI-Agents.md>)
  - [Discovery Suggestions for MCP Servers](<./AI-Agent-Discovery-Inbox/Discovery-Suggestions-for-MCP-Servers.md>)
  - [Accessing the AI Agent Discovery Inbox](<./AI-Agent-Discovery-Inbox/Accessing-the-AI-Agent-Discovery-Inbox.md>)
  - [Filtering and Searching in the Discovery Inbox](<./AI-Agent-Discovery-Inbox/Filtering-and-Searching-in-the-Discovery-Inbox.md>)
  - [Quick Filters](<./AI-Agent-Discovery-Inbox/Quick-Filters.md>)
  - [Linking to Suggested Fact Sheets](<./AI-Agent-Discovery-Inbox/Linking-to-Suggested-Fact-Sheets.md>)
  - [Linking Beyond Suggested Fact Sheets](<./AI-Agent-Discovery-Inbox/Linking-Beyond-Suggested-Fact-Sheets.md>)
  - [Linking Discovered Items in Bulk](<./AI-Agent-Discovery-Inbox/Linking-Discovered-Items-in-Bulk.md>)
  - [Changing Existing Links to Fact Sheets](<./AI-Agent-Discovery-Inbox/Changing-Existing-Links-to-Fact-Sheets.md>)
  - [Rejecting Discovered Inbox Items](<./AI-Agent-Discovery-Inbox/Rejecting-Discovered-Inbox-Items.md>)
  - [Rejecting Discovered Items in Bulk](<./AI-Agent-Discovery-Inbox/Rejecting-Discovered-Items-in-Bulk.md>)
  - [Was this page helpful?](<./AI-Agent-Discovery-Inbox/Was-this-page-helpful.md>)
